@@ -2,6 +2,7 @@ package quote
 
 import (
 	c "github.com/achannarasappa/ticker/internal/common"
+	quoteCoincap "github.com/achannarasappa/ticker/internal/quote/coincap"
 	quoteCoingecko "github.com/achannarasappa/ticker/internal/quote/coingecko"
 	quoteYahoo "github.com/achannarasappa/ticker/internal/quote/yahoo"
 	"github.com/go-resty/resty/v2"
@@ -17,6 +18,10 @@ func getQuoteBySource(dep c.Dependencies, symbolBySource c.AssetGroupSymbolsBySo
 		return quoteCoingecko.GetAssetQuotes(*dep.HttpClients.Default, symbolBySource.Symbols)
 	}
 
+	if symbolBySource.Source == c.QuoteSourceCoinCap {
+		return quoteCoincap.GetAssetQuotes(*dep.HttpClients.Default, symbolBySource.Symbols)
+	}
+
 	return []c.AssetQuote{}
 }
 
@@ -80,7 +85,7 @@ func getUniqueSymbolsBySource(assetGroups []c.AssetGroup) []c.AssetGroupSymbolsB
 }
 
 // GetAssetGroupsCurrencyRates gets the currency rates by source across all asset groups
-func GetAssetGroupsCurrencyRates(client resty.Client, assetGroups []c.AssetGroup, targetCurrency string) (c.CurrencyRates, error) {
+func GetAssetGroupsCurrencyRates(client *resty.Client, assetGroups []c.AssetGroup, targetCurrency string) (c.CurrencyRates, error) {
 
 	var err error
 	var currencyRates c.CurrencyRates
@@ -89,7 +94,7 @@ func GetAssetGroupsCurrencyRates(client resty.Client, assetGroups []c.AssetGroup
 	for _, source := range uniqueSymbolsBySource {
 
 		if source.Source == c.QuoteSourceYahoo && err == nil {
-			currencyRates, err = quoteYahoo.GetCurrencyRates(client, source.Symbols, targetCurrency)
+			currencyRates, err = quoteYahoo.GetCurrencyRates(*client, source.Symbols, targetCurrency)
 		}
 
 	}
